---
title: <span class="badge object-type-scalar"></span> Days
---
# <span class="badge object-type-scalar"></span> Days

Time: days (d)

## Definition

```python
# Time: days (d)
Days: typing.Literal["d"] = "d"
```
